@@ -20,6 +20,7 @@ from honeybee.typing import float_positive
 from honeybee.checkdup import check_duplicate_identifiers
 from honeybee.units import conversion_factor_to_meters, UNITS, UNITS_TOLERANCES
 from honeybee.config import folders
+from honeybee.room import Room
 
 from ._base import _BaseGeometry
 from .properties import ModelProperties
@@ -235,10 +236,15 @@ class Model(_BaseGeometry):
         assert data['type'] == 'Model', 'Expected Model dictionary. ' \
             'Got {}.'.format(data['type'])
 
-        # import the tolerance values
-        tol = None if 'tolerance' not in data else data['tolerance']
-        angle_tol = 1.0 if 'angle_tolerance' not in data else data['angle_tolerance']
+        # import the units and tolerance values
+        units = 'Meters' if 'units' not in data or data['units'] is None \
+            else data['units']
+        tol = UNITS_TOLERANCES[units] if 'tolerance' not in data or \
+            data['tolerance'] is None else data['tolerance']
+        angle_tol = 1.0 if 'angle_tolerance' not in data or \
+            data['angle_tolerance'] is None else data['angle_tolerance']
 
+        # import all of the geometry
         buildings = None  # import buildings
         if 'buildings' in data and data['buildings'] is not None:
             buildings = [Building.from_dict(bldg, tol) for bldg in data['buildings']]
@@ -246,9 +252,6 @@ class Model(_BaseGeometry):
         if 'context_shades' in data and data['context_shades'] is not None:
             context_shades = [ContextShade.from_dict(s) for s in data['context_shades']]
 
-        # import the units
-        units = 'Meters' if 'units' not in data else data['units']
-
         # build the model object
         model = Model(data['identifier'], buildings, context_shades,
                       units, tol, angle_tol)
@@ -635,7 +638,8 @@ class Model(_BaseGeometry):
         return ''
 
     def to_honeybee(self, object_per_model='Building', shade_distance=None,
-                    use_multiplier=True, add_plenum=False, cap=False, tolerance=None):
+                    use_multiplier=True, add_plenum=False, cap=False,
+                    solve_ceiling_adjacencies=False, tolerance=None):
         """Convert Dragonfly Model to an array of Honeybee Models.
 
         Args:
@@ -674,6 +678,11 @@ class Model(_BaseGeometry):
                 with a top face. Usually, this is not necessary to account for
                 blocked sun and is only needed when it's important to account for
                 reflected sun off of roofs. (Default: False).
+            solve_ceiling_adjacencies: Boolean to note whether adjacencies should be
+                solved between interior stories when Room2Ds perfectly match one
+                another in their floor plate. This ensures that Surface boundary
+                conditions are used instead of Adiabatic ones. Note that this input
+                has no effect when the object_per_model is Story. (Default: False).
             tolerance: The minimum distance in z values of floor_height and
                 floor_to_ceiling_height at which adjacent Faces will be split.
                 This is also used in the generation of Windows. This must be a
@@ -708,6 +717,12 @@ class Model(_BaseGeometry):
             raise ValueError('Unrecognized object_per_model input: '
                              '{}'.format(object_per_model))
 
+        # solve ceiling adjacencies if requested
+        if solve_ceiling_adjacencies and \
+                object_per_model.title() in ('Building', 'District'):
+            for model in models:
+                Room.solve_adjacency(model.rooms, tolerance)
+
         # change the tolerance and units systems to match the dragonfly model
         for model in models:
             model.units = self.units
